Crate kcr_core_openfeature_dev

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the core.openfeature.dev group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

core.openfeature.dev/v1alpha1

  • FeatureFlagConfiguration

core.openfeature.dev/v1alpha2

  • FeatureFlagConfiguration

Modules

v1alpha1
v1alpha2